@@ -30,7 +30,7 @@ extern "C" {
 #define MagickLibVersion  0x707
 #define MagickLibVersionText  "7.0.7"
 #define MagickLibVersionNumber  5,0,0
-#define MagickLibAddendum  "-21"
+#define MagickLibAddendum  "-23"
 #define MagickLibInterface  5
 #define MagickLibMinInterface  5
 #if defined(_WINDOWS)
@@ -40,14 +40,14 @@ extern "C" {
 #    define MagickPlatform "x86"
 #  endif
 #else
-#define MagickPlatform  "armv5tel"
+#define MagickPlatform  "armv7l"
 #endif
 #define MagickppLibVersionText  "7.0.7"
 #define MagickppLibVersionNumber  4:0:0
-#define MagickppLibAddendum  "-21"
+#define MagickppLibAddendum  "-23"
 #define MagickppLibInterface  4
 #define MagickppLibMinInterface  4
-#define MagickReleaseDate  "2018-01-12"
+#define MagickReleaseDate  "2018-02-19"
 #define MagickAuthoritativeLicense  \
   "http://www.imagemagick.org/script/license.php"
 #define MagickAuthoritativeURL  "http://www.imagemagick.org"
